Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CatFile ¶
type CatFile struct {
// contains filtered or unexported fields
}
CatFile is for reading a whole file.
func NewCatFile ¶
func NewCatFile(filePath string, globID string, serverMessages chan<- string, limiter chan struct{}) CatFile
NewCatFile returns a new file catter.
type FileReader ¶
type FileReader interface {
Start(lines chan<- LineRead, regex string) error
FilePath() string
Retry() bool
Stop()
}
FileReader is the interface used on the dtail server to read/cat/grep/mapr... a file.
type LineRead ¶
type LineRead struct {
// The content of the log line.
Content []byte
// Until now, how many log lines were processed?
Count uint64
// Sometimes we produce too many log lines so that the client
// is too slow to process all of them. The server will drop log
// lines if that happens but it will signal to the client how
// many log lines in % could be transmitted to the client.
TransmittedPerc int
GlobID *string
}
LineRead represents a read log line.
type TailFile ¶
type TailFile struct {
// contains filtered or unexported fields
}
TailFile is to tail and filter a log file.
func NewTailFile ¶
func NewTailFile(filePath string, globID string, serverMessages chan<- string, limiter chan struct{}) TailFile
NewTailFile returns a new file tailer.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.